@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-b06c64eca876b2bde276809d07840573
-key: vecto_Az84Iak3JmYKyGzEsrZjVC
+id: vector-instances-3.3.1-58179fcd4f5e524f89d8d30f0f28d3d1
+key: vecto_IqI2Z1FlkEI4wN4cUy4e7q
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,13 +17,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-Az84Iak3JmYKyGzEsrZjVC
+hs-libraries: HSvector-instances-3.3.1-IqI2Z1FlkEI4wN4cUy4e7q
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-caa084d849f0fd836e529854caff7fc2
-    keys-3.11-3d8e7ac6dad4b2be59ab23649a19b0c5
-    pointed-5-517604c53148c16ee342915b24abeef1
-    semigroupoids-5.0.1-71b3eb635555631c006bdf0054367a98
+    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
+    keys-3.11-e8b0d316d522e372d8b8151d1187a042
+    pointed-5-cd769d29c367a186cee815cfa6956cb1
+    semigroupoids-5.0.1-e4734876ceb621b0eefb491ac209dad3
     semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
